@@ -399,8 +399,8 @@ def _plot_supports(node_tags, ax):
 
         node_dofs = ops.nodeDOFs(node_tag)
 
+        m_type = None
         m_color = 'm'
-        m_type = ''
         m_fstyle = 'full'
 
         if ndf < 3:
@@ -416,6 +416,7 @@ def _plot_supports(node_tags, ax):
                 m_type = path_roller_horiz
                 m_fstyle = 'full'
                 m_size = 16
+
         else:
             if (node_dofs[0] == -1 and node_dofs[1] == -1 and node_dofs[2] == -1):
                 m_type = path_fix
@@ -434,8 +435,9 @@ def _plot_supports(node_tags, ax):
                 m_fstyle = 'full'
                 m_size = 16
 
-        ax.plot(nd_crd[0], nd_crd[1], marker=m_type, markersize=m_size,
-                color=m_color, fillstyle=m_fstyle)
+        if m_type:
+            ax.plot(nd_crd[0], nd_crd[1], marker=m_type, markersize=m_size,
+                    color=m_color, fillstyle=m_fstyle)
 
     return ax
 
@@ -520,8 +522,7 @@ def _plot_model_3d(node_labels, element_labels, offset_nd_label, axis_off,
         if (ele_classtag == EleClassTag.ElasticBeam3d or
             ele_classtag == EleClassTag.ForceBeamColumn3d or
             ele_classtag == EleClassTag.DispBeamColumn3d or
-            ele_classtag == EleClassTag.ElasticTimoshenkoBeam3d or
-            ele_classtag == EleClassTag.truss):
+            ele_classtag == EleClassTag.ElasticTimoshenkoBeam3d):
 
             nen = 2
             ele_node_tags = ops.eleNodes(ele_tag)
@@ -577,6 +578,45 @@ def _plot_model_3d(node_labels, element_labels, offset_nd_label, axis_off,
                 ax.quiver(xt, yt, zt, g[2, 0], g[2, 1], g[2, 2], color='r',
                           lw=2, length=alen, alpha=.8, normalize=True)
 
+        elif (ele_classtag == EleClassTag.truss):
+
+            nen = 2
+            ele_node_tags = ops.eleNodes(ele_tag)
+
+            ecrd = np.zeros((nen, 3))
+
+            for i, ele_node_tag in enumerate(ele_node_tags):
+                ecrd[i, :] = ops.nodeCoord(ele_node_tag)
+
+            # location of label
+            xt = sum(ecrd[:, 0]) / nen
+            yt = sum(ecrd[:, 1]) / nen
+            zt = sum(ecrd[:, 2]) / nen
+
+            ax.plot(ecrd[:, 0], ecrd[:, 1], ecrd[:, 2], **fmt_model)
+
+            # fixme: placement of node_tag labels
+            if element_labels:
+                if ecrd[1, 0] - ecrd[0, 0] == 0:
+                    va = 'center'
+                    ha = 'left'
+                    offset_x, offset_y, offset_z = _offset, 0.0, 0.0
+                elif ecrd[1, 1] - ecrd[0, 1] == 0:
+                    va = 'bottom'
+                    ha = 'center'
+                    offset_x, offset_y, offset_z = 0.0, _offset, 0.0
+                elif ecrd[1, 2] - ecrd[0, 2] == 0:
+                    va = 'bottom'
+                    ha = 'center'
+                    offset_x, offset_y, offset_z = 0.0, 0.0, _offset
+                else:
+                    va = 'bottom'
+                    ha = 'left'
+                    offset_x, offset_y, offset_z = 0.03, 0.03, 0.03
+
+                ax.text(xt+offset_x, yt+offset_y, zt+offset_z, f'{ele_tag}',
+                        va=va, ha=ha, color='red')
+
         # quad in 3d
         # elif nen == 4:
         elif ele_classtag == EleClassTag.FourNodeTetrahedron:
@@ -1427,6 +1467,50 @@ def get_Ew_data_from_ops_domain():
     return Ew
 
 
+def get_Ew_data_from_ops_domain_3d():
+
+    Ew = {}
+    ibeg = 0
+    iend = 0
+    ele_load_tags_all_patterns = ops.getEleLoadTags()
+    ele_load_types_all_patterns = ops.getEleLoadClassTags()
+    ele_load_data_all_patterns = ops.getEleLoadData()
+
+    for ele_load_tag in ele_load_tags_all_patterns:
+        Ew[ele_load_tag] = []
+
+    # iterate over ele_load_tags/classtags
+    for ele_load_type, ele_load_tag in zip(ele_load_types_all_patterns,
+                                           ele_load_tags_all_patterns):
+
+        # -beamUniform
+        if ele_load_type == LoadTag.Beam3dUniformLoad:
+            iend = ibeg+LoadTag.Beam3dUniformLoad_ndata
+            ele_load_data = ele_load_data_all_patterns[ibeg:iend]
+            ibeg = iend
+            wy, wz, wx = ele_load_data[0], ele_load_data[1]
+            Ew[ele_load_tag].append(['-beamUniform', wy, wy, wx])
+        # -beamUniform partial
+        elif ele_load_type == LoadTag.Beam3dPartialUniformLoad:
+            iend = ibeg+LoadTag.Beam3dPartialUniformLoad_ndata
+            ele_load_data = ele_load_data_all_patterns[ibeg:iend]
+            ibeg = iend
+            wy, wz, wa, aL, bL = ele_load_data
+            Ew[ele_load_tag].append(['-beamUniform', wy, wz, wa, aL, bL])
+        # -beamPoint
+        elif ele_load_type == LoadTag.Beam3dPointLoad:
+            iend = ibeg+LoadTag.Beam3dPointLoad_ndata
+            ele_load_data = ele_load_data_all_patterns[ibeg:iend]
+            ibeg = iend
+            Py, Pz, Px, aL = ele_load_data
+            Ew[ele_load_tag].append(['-beamPoint', Py, Pz, aL, Px])
+        else:
+            print(f'\nWarning! ele_load_type:\n{ele_load_type} - Unknown element load Error')
+
+
+    return Ew
+
+
 def plot_extruded_shapes_3d(ele_shapes, az_el=az_el,
                             fig_wi_he=False,
                             fig_lbrt=False, ax=False):
